
#ifndef _C12_kl571_
#define _C12_kl571_

#ifdef __cplusplus
extern "C" {
#endif

RTOSHF (EIF_REFERENCE,9206)
static EIF_REFERENCE F660_9206_body(EIF_REFERENCE);
extern EIF_REFERENCE F660_9206(EIF_REFERENCE);
extern void EIF_Minit571(void);

#ifdef __cplusplus
}
#endif

#endif
